@@ -1,11 +1,8 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright (c) 2022, MaidSafe.
+// All rights reserved.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// https://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed under the BSD-3-Clause license.
+// Please see the LICENSE file for more details.
 
 use crate::dev_utils::{create_ids, PeerId};
 use crate::key_gen::{message::Message, Error, KeyGen, MessageAndTarget};
@@ -73,7 +70,7 @@ fn create_generators<R: RngCore>(
 
 fn messaging<R: RngCore>(
     mut rng: &mut R,
-    generators: &mut Vec<KeyGen>,
+    generators: &mut [KeyGen],
     proposals: &mut Vec<MessageAndTarget>,
     non_responsives: BTreeSet<u64>,
 ) {
